/* eslint-env browser */
/* eslint-disable no-alert */

import "./preloaded1.css";

alert("Ok");
